@@ -3,7 +3,6 @@ from __future__ import absolute_import, unicode_literals
 import os
 import sentry_sdk
 
-from celery import Celery
 # set the default Django settings module for the 'celery' program.
 from django.conf import settings
 
@@ -18,13 +17,14 @@ dotenv_path = find_dotenv(
     usecwd=True
 )
 print('Load dotenv configuration from %s' % dotenv_path)
-load_dotenv(dotenv_path=dotenv_path)
+load_dotenv(dotenv_path=dotenv_path, override=True)
 
 os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
 import configurations
 configurations.setup()
 
+from celery import Celery
 app = Celery('crm')
 # app.config_from_object('django.conf:settings')
 # app.autodiscover_tasks(lambda: settings.INSTALLED_APPS)
