@@ -20,7 +20,7 @@ try:
         usecwd=True
     )
     print('Load dotenv configuration from %s' % dotenv_path)
-    load_dotenv(dotenv_path=dotenv_path)
+    load_dotenv(dotenv_path=dotenv_path, override=True)
 
     os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 except BaseException as e:
